/// <reference types="node" />
import WebSocket, { WebSocketServer } from 'ws';
import { IncomingMessage, Server as HTTPServer } from 'http';
import { Configuration, Hook } from './types';
import { MessageLogger } from './Debugger';
export declare const defaultConfiguration: {
    name: null;
    port: number;
    timeout: number;
};
/**
 * Hocuspocus server
 */
export declare class Hocuspocus {
    configuration: Configuration;
    documents: Map<any, any>;
    httpServer?: HTTPServer;
    webSocketServer?: WebSocketServer;
    debugger: MessageLogger;
    /**
     * Configure the server
     */
    configure(configuration: Partial<Configuration>): Hocuspocus;
    get authenticationRequired(): boolean;
    /**
     * Start the server
     */
    listen(): Promise<void>;
    /**
     * Get the total number of active documents
     */
    getDocumentsCount(): number;
    /**
     * Get the total number of active connections
     */
    getConnectionsCount(): number;
    /**
     * Force close one or more connections
     */
    closeConnections(documentName?: string): void;
    /**
     * Destroy the server
     */
    destroy(): Promise<any>;
    /**
     * Handle the incoming WebSocket connection
     */
    handleConnection(incoming: WebSocket, request: IncomingMessage, documentName: string, context?: any): void;
    /**
     * Handle update of the given document
     * @private
     */
    private handleDocumentUpdate;
    /**
     * Create a new document by the given request
     * @private
     */
    private createDocument;
    /**
     * Create a new connection by the given request and document
     * @private
     */
    private createConnection;
    /**
     * Run the given hook on all configured extensions
     * Runs the given callback after each hook
     */
    hooks(name: Hook, payload: any, callback?: Function | null): Promise<any>;
    /**
     * Get parameters by the given request
     * @private
     */
    private static getParameters;
    /**
     * Get document name by the given request
     * @private
     */
    private getDocumentNameFromRequest;
    enableDebugging(): void;
    enableMessageLogging(): void;
    disableLogging(): void;
    disableDebugging(): void;
    flushMessageLogs(): this;
    getMessageLogs(): any[];
}
export declare const Server: Hocuspocus;
